@@ -13,9 +13,9 @@ import natsort
 import time
 import datetime
 # mine
-import hwrt.preprocess_dataset as preprocess_dataset
-import hwrt.create_pfiles as create_pfiles
-import hwrt.create_model as create_model
+import preprocess_dataset
+import create_pfiles
+import create_model
 
 
 def print_status(total, current, start_time=None):
